@@ -14,9 +14,9 @@ BINARY_OPERATORS = {
     "!=": "notEqual",
     "&&": "land",
     "<": "lessThan",
-    "<=": "lessTnanEq",
+    "<=": "lessThanEq",
     ">": "greaterThan",
-    ">=": "greaterTnanEq",
+    ">=": "greaterThanEq",
     "===": "strictEqual",
     "<<": "shl",
     ">>": "shr",
